@@ -49,7 +49,7 @@ lmnopqrst
 >>> 
 """
 
-__version__ = "2.0.0"
+__version__ = "3.0.0"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -227,12 +227,16 @@ class Strings:
             return True, True
 
 
-def parse_arguments() -> Namespace:
+def parse_arguments(parser: ArgumentParser = None) -> Namespace:
     """
     This function parses command line arguments.
     """
 
-    parser = ArgumentParser()
+    if parser is None:
+        parser = ArgumentParser(
+            description="This script exports strings from binary file."
+        )
+
     parser.add_argument("filename", help="Filename of binary file.")
     parser.add_argument(
         "--minimum-length",
